==> Squeak3.0.2-MacOSX-VM.tar.gz: Squeak-MacOSX-VM-3.0.2-2001.04.16.sb/src/Squeak/SqueakInterpreter.h <==
/* SqueakInterpreter.h created by marcel on Tue 19-Dec-2000 */

#import <Foundation/Foundation.h>
#import <Squeak/AccessorMacros.h>

@protocol SqueakDisplayServing

-(int)ioScreenSize;
-(int)ioSetCursorBitsIndex:(int)cursorBitsIndex
                  withMask:(int)cursorMaskIndex
                   offsetX:(int)x offsetY:(int)y;
-(int)ioSetCursorBitsIndex:(int)cursorBitsIndex
                   offsetX:(int)x offsetY:(int)y;
-(int)ioShowDisplayBitsIndex:(int)bInd
                       width:(int)w height:(int)h depth:(int)d
                affectedLeft:(int)l affectedRight:(int)r
                 affectedTop:(int)t affectedBottom:(int)b;

@end

@protocol SqueakInputSensor

-(int)ioGetButtonState;
-(int)ioGetKeystroke;
-(int)ioMousePoint;
-(int)ioPeekKeystroke;

@end


@interface SqueakInterpreter : NSObject
{
    //---	I/O helpers
    
    id	display;
    id	inputSensor;
    id	eventSensor;
    id	soundServer;
    id	clipHandler;
    
    //---	various interpreter parms

    id		imagePath;
    id		vmPath;
    int		inputEventSemaphore;

    id		specialAttributes;
    id		argvAttributes;
    NSTimeInterval startupTimeInterval;

    id		eventQueue;
    BOOL 	interpreterRunning;

    id		squeakMemory;
    NSTimeInterval lowResMSTime;
    id	timer;
}

+interpreter;
-(void)startInterpreter;
-(void)stopInterpreter;

-(void)startInterpreterInSeparateThread;
-(BOOL)readImageFile:(NSString*)imagePath withHeapSize:(int)heapSize;
-(void)interrupt;

accessor_h( display, setDisplay )
accessor_h( inputSensor, setInputSensor )
accessor_h( soundServer, setSoundServer )
    accessor_h( imagePath, setImagePath )
    accessor_h( vmPath, setVmPath )
    intAccessor_h( stackCacheEntries, setStackCacheEntries )
    intAccessor_h( contextCacheEntries, setContextCacheEntries )
    accessor_h( argvAttributes, setArgvAttributes )
    accessor_h( specialAttributes, setSpecialAttributes )
    accessor_h( clipHandler, setClipHandler )
boolAccessor_h( interpreterRunning , setInterpreterRunning )
    accessor_h( eventQueue, setEventQueue )


@end

==> Squeak3.0.3-MacOSX-VM.tar.gz: Squeak-MacOSX-VM-3.0.3-2001.06.05.sb/src/Squeak/SqueakInterpreter.h <==
/* SqueakInterpreter.h created by marcel on Tue 19-Dec-2000 */

#import <Foundation/Foundation.h>
#import <Squeak/AccessorMacros.h>

@protocol SqueakDisplayServing

-(int)ioScreenSize;
-(int)ioSetCursorBitsIndex:(int)cursorBitsIndex
                  withMask:(int)cursorMaskIndex
                   offsetX:(int)x offsetY:(int)y;
-(int)ioSetCursorBitsIndex:(int)cursorBitsIndex
                   offsetX:(int)x offsetY:(int)y;
-(int)ioShowDisplayBitsIndex:(int)bInd
                       width:(int)w height:(int)h depth:(int)d
                affectedLeft:(int)l affectedRight:(int)r
                 affectedTop:(int)t affectedBottom:(int)b;

@end

@protocol SqueakInputSensor

-(int)ioGetButtonState;
-(int)ioGetKeystroke;
-(int)ioMousePoint;
-(int)ioPeekKeystroke;

@end


@interface SqueakInterpreter : NSObject
{
    //---	I/O helpers
    
    id	display;
    id	inputSensor;
    id	eventSensor;
    id	soundServer;
    id	clipHandler;
    
    //---	various interpreter parms

    id		imagePath;
    id		vmPath;
    int		inputEventSemaphore;

    id		specialAttributes;
    id		argvAttributes;
    NSTimeInterval startupTimeInterval;

    id		eventQueue;
    BOOL 	interpreterRunning;

    id		squeakMemory;
    NSTimeInterval lowResMSTime;
    id	timer;
}

+interpreter;
-(void)startInterpreter;
-(void)stopInterpreter;

-(void)startInterpreterInSeparateThread;
-(BOOL)readImageFile:(NSString*)imagePath withHeapSize:(int)heapSize;
-(void)interrupt;

idAccessor_h( display, setDisplay )
idAccessor_h( inputSensor, setInputSensor )
idAccessor_h( soundServer, setSoundServer )
    idAccessor_h( imagePath, setImagePath )
    idAccessor_h( vmPath, setVmPath )
    intAccessor_h( stackCacheEntries, setStackCacheEntries )
    intAccessor_h( contextCacheEntries, setContextCacheEntries )
    idAccessor_h( argvAttributes, setArgvAttributes )
    idAccessor_h( specialAttributes, setSpecialAttributes )
    idAccessor_h( clipHandler, setClipHandler )
boolAccessor_h( interpreterRunning , setInterpreterRunning )
    idAccessor_h( eventQueue, setEventQueue )


@end
